# cv3: Pythonic OpenCV to speed up your computer vision research

## Principles
- Solve more important tasks than writing extra code
- You are programming in python, not C++
- OpenCV is not scary

## Features
You can get acquainted with the features in [demo.ipynb](https://github.com/gorodion/pycv/blob/main/demo.ipynb)
- Forget to remember extra parameters. To draw a square you don't need to know color and thickness. 
- Forget to type everything. You can pass float/pathlib.Path arguments where cv2 doesn't allow
- Forget to copy the same code over and over (like cv2.getRotationMatrix2D or cv2.VideoWriter_fourcc(*'MP4V'))

## Quick start
`pip install git+https://github.com/gorodion/pycv.git`

[demo.ipynb](https://github.com/gorodion/pycv/blob/main/demo.ipynb)

## Run tests
```python
pytest -v
```
---
I hope this is helpful, please contribute 🙂
